@@ -423,8 +423,10 @@ class SignalGroupDescriptor:
 
             # clean up the cache when the instance is deleted
             with contextlib.suppress(TypeError):
-                # mypy says too many attributes for weakref.finalize, but it's wrong.
-                weakref.finalize(instance, self._instance_map.pop, obj_id, None)  # type: ignore [call-arg]  # noqa
+                # on 3.7 this is type error, above it's not... but mypy yells about
+                # type ignore on 3.8+, so we do this funny business instead.
+                args = (instance, self._instance_map.pop, obj_id, None)
+                weakref.finalize(*args)  # type: ignore
 
         return self._instance_map[obj_id]
 
