@@ -7,6 +7,14 @@ from unittest.mock import Mock
 import numpy as np
 import pytest
 
+try:
+    import pydantic.version
+
+    PYDANTIC_V2 = pydantic.version.VERSION.startswith("2")
+except ImportError:
+    PYDANTIC_V2 = False
+
+
 from psygnal import (
     SignalGroup,
     SignalGroupDescriptor,
@@ -105,12 +113,17 @@ def test_attrs_dataclass(decorator: bool, slots: bool) -> None:
     _check_events(Foo)
 
 
-class Config:
-    arbitrary_types_allowed = True
+if PYDANTIC_V2:
+    Config = {"arbitrary_types_allowed": True}
+else:
+
+    class Config:
+        arbitrary_types_allowed = True
 
 
 @decorated_or_descriptor
 def test_pydantic_dataclass(decorator: bool) -> None:
+    pytest.importorskip("pydantic")
     from pydantic.dataclasses import dataclass
 
     @dataclass(config=Config)
@@ -135,6 +148,7 @@ def test_pydantic_dataclass(decorator: bool) -> None:
 
 @decorated_or_descriptor
 def test_pydantic_base_model(decorator: bool) -> None:
+    pytest.importorskip("pydantic")
     from pydantic import BaseModel
 
     class Base(BaseModel):
@@ -142,7 +156,10 @@ def test_pydantic_base_model(decorator: bool) -> None:
         baz: str
         qux: np.ndarray
 
-        Config = Config  # type: ignore
+        if PYDANTIC_V2:
+            model_config = Config
+        else:
+            Config = Config  # type: ignore
 
     if decorator:
 
